@@ -1,8 +1,8 @@
 package XS::Log;
-#Build  MD5 : R1MY9FhOM6oCh4gZqAS+WA
-#Build Time : 2025-09-18 11:29:52
-our $VERSION = 1.03;
-our $BUILDDATE = "2025-09-18";  #Build Time: 11:29:52
+#Build  MD5 : drVn1p6ygZRWEQSVolq0tg
+#Build Time : 2025-09-18 13:23:17
+our $VERSION = 1.04;
+our $BUILDDATE = "2025-09-18";  #Build Time: 13:23:17
 use strict;
 use warnings;
 use XSLoader;
@@ -46,9 +46,9 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
  use XS::Log qw(:all);
  
  my %opt = (
-     level             => Log::LOG_LEVEL_DEBUG,
-     mode              => Log::LOG_MODE_DAILY,
-     targets           => Log::LOG_TARGET_CONSOLE | Log::LOG_TARGET_FILE,
+     level             => LOG_LEVEL_DEBUG,
+     mode              => LOG_MODE_DAILY,
+     targets           => LOG_TARGET_CONSOLE | LOG_TARGET_FILE,
      use_color         => 1,
      show_timestamp    => 1,
      show_log_level    => 1,
@@ -111,7 +111,7 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
 =head3 options参数
 
   level                  #日志级别，默认： LOG_LEVEL_INFO
-  mode 				     #日志模式，默认： LOG_MODE_CYCLE
+  mode                   #日志模式，默认： LOG_MODE_CYCLE
   targets                #输出目标组合(位掩码)，默认： LOG_TARGET_CONSOLE
   use_color;             #是否使用彩色输出(控制台)，默认：1
   show_timestamp;        #是否显示时间戳，默认：1
@@ -123,11 +123,11 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
 
 =head2 closeLog
 
-  closeLog();			#关闭日志文件
+  closeLog();            #关闭日志文件
   
 =head2 flushLog
 
-  flushLog();			#flush日志缓存
+  flushLog();           #flush日志缓存
 
 =head2 setLogConf 
 
@@ -135,19 +135,19 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
 
 =head2 setLogUseColor 
 
-  setLogUseColor($bool);		#设置日志颜色，0-无颜色 1-有颜色
+  setLogUseColor($bool);        #设置日志颜色，0-无颜色 1-有颜色
 
 =head2 setLogTargets
 
-  setLogTargets($target);		#设置日志输出日志模式，LOG_TARGET_CONSOLE/LOG_TARGET_FILE
+  setLogTargets($target);       #设置日志输出日志模式，LOG_TARGET_CONSOLE/LOG_TARGET_FILE
  
 =head2 setLogMode
  
-  setLogMode($mode)				#设置日志文件循环模式
+  setLogMode($mode);            #设置日志文件循环模式
 
 =head2 setLogLevel
  
-  setLogLevel($level)			#设置日志级别
+  setLogLevel($level);          #设置日志级别
 
 =head2 日志输出命令
 
@@ -164,4 +164,3 @@ B<XS::Log>是高效快速的日志模块，纯c语言开发，快速高效的IO
 
 =cut
 
-
